==> fxgui-2.2.1.tar.gz: fxgui-2.2.1/README.md <==
<p align="left">
  <a href="https://www.python.org">
  <img src="https://img.shields.io/badge/-Python-FFD43B?style=for-the-badge&logo=python" alt="Python"/></a>
  <img src="https://img.shields.io/badge/-PySide-284821?style=for-the-badge&logo=qt" alt="Python"/></a>
  <img src="https://img.shields.io/badge/-Windows-00A4EF?style=for-the-badge&logo=windows" alt="Compatible with Windows"/></a>
  <img src="https://img.shields.io/badge/-macOS-000000?style=for-the-badge&logo=apple" alt="Compatible with macOS"/></a>
  <img src="https://img.shields.io/badge/-Linux-E95420?style=for-the-badge&logo=linux" alt="Compatible with Linux"/></a>
</p>

<div align="center">

  ![Logo](./fxgui/images/fxgui_logo_dark.svg#gh-light-mode-only)
  ![Logo](./fxgui/images/fxgui_logo_light.svg#gh-dark-mode-only)

  <h3 align="center">FXGUI</h3>

  <p align="center">
    Custom Python classes and utilities tailored for Qt built UI, in VFX-oriented DCC applications.
    <br/>
    <br/>
    <br/>
  </p>

</div>



<!-- TABLE OF CONTENTS -->
## Table of Contents
<!--ts-->
- [Table of Contents](#table-of-contents)
- [About](#about)
- [Installation](#installation)
- [Example](#example)
- [Documentation](#documentation)
- [Contact](#contact)
<!--te-->



<!-- ABOUT -->
## About

Custom Python classes and utilities tailored for Qt built UI, in VFX-oriented DCC applications.



<!-- INSTALLATION -->
## Installation

``` shell
pip install fxgui
```

> [!IMPORTANT]
> In order to have access to the module, make sure to add `fxgui` to the `$PYTHONPATH` of the DCCs. For Houdini, you can find the [houdini_package file](./houdini_package.json).



<!-- EXAMPLE -->
## Example

After installing fxgui, you can run the demo:

``` shell
python example.py
```

Or:

``` python
from fxgui import examples

examples.main()
```



<!-- DOCUMENTATION -->
## Documentation

Please read the full documentation [here](https://healkeiser.github.io/fxgui/).



<!-- CONTACT -->
## Contact

Project Link: [fxgui](https://github.com/healkeiser/fxgui)

<p align='left'>
  <a href="https://www.linkedin.com/in/valentin-beaumont">
  <img src="https://img.shields.io/badge/-LinkedIn-0A66C2?style=for-the-badge&logo=linkedin" alt="LinkedIn"/></a>
  <a href="https://www.behance.net/el1ven">
  <img src="https://img.shields.io/badge/-Behance-313131?style=for-the-badge&logo=behance" alt="Behance"/></a>
  <a href="https://twitter.com/valentinbeaumon">
  <img src="https://img.shields.io/badge/-Twitter-E1E8ED?style=for-the-badge&logo=twitter" alt="Twitter"/></a>
  <a href="https://www.instagram.com/val.beaumontart">
  <img src="https://img.shields.io/badge/-Instagram-85255b?style=for-the-badge&logo=instagram" alt="Instagram"/></a>
  <a href="https://healkeiser.gumroad.com/subscribe">
  <img src="https://img.shields.io/badge/-Gumroad-20151f?style=for-the-badge&logo=gumroad" alt="Gumroad"/></a>
</p>

[!["Buy Me A Coffee"](https://www.buymeacoffee.com/assets/img/custom_images/yellow_img.png)](https://www.buymeacoffee.com/healkeiser)

==> fxgui-2.2.2.tar.gz: fxgui-2.2.2/README.md <==
<p align="left">
  <a href="https://www.python.org">
  <img src="https://img.shields.io/badge/-Python-FFD43B?style=for-the-badge&logo=python" alt="Python"/></a>
  <img src="https://img.shields.io/badge/-PySide-284821?style=for-the-badge&logo=qt" alt="Python"/></a>
  <img src="https://img.shields.io/badge/-Windows-00A4EF?style=for-the-badge&logo=windows" alt="Compatible with Windows"/></a>
  <img src="https://img.shields.io/badge/-macOS-000000?style=for-the-badge&logo=apple" alt="Compatible with macOS"/></a>
  <img src="https://img.shields.io/badge/-Linux-E95420?style=for-the-badge&logo=linux" alt="Compatible with Linux"/></a>
</p>

<div align="center">

  ![Logo](https://raw.githubusercontent.com/healkeiser/fxgui/main/fxgui/images/fxgui_logo_dark.svg#gh-light-mode-only)
  ![Logo](https://raw.githubusercontent.com/healkeiser/fxgui/main/fxgui/images/fxgui_logo_light.svg#gh-dark-mode-only)

  <h3 align="center">FXGUI</h3>

  <p align="center">
    Custom Python classes and utilities tailored for Qt built UI, in VFX-oriented DCC applications.
    <br/>
    <br/>
    <br/>
  </p>

</div>



<!-- TABLE OF CONTENTS -->
## Table of Contents
<!--ts-->
- [Table of Contents](#table-of-contents)
- [About](#about)
- [Installation](#installation)
- [Example](#example)
- [Documentation](#documentation)
- [Contact](#contact)
<!--te-->



<!-- ABOUT -->
## About

Custom Python classes and utilities tailored for Qt built UI, in VFX-oriented DCC applications.



<!-- INSTALLATION -->
## Installation

``` shell
pip install fxgui
```

> [!IMPORTANT]
> In order to have access to the module, make sure to add `fxgui` to the `$PYTHONPATH` of the DCCs. For Houdini, you can find the [houdini_package file](./houdini_package.json).



<!-- EXAMPLE -->
## Example

After installing fxgui, you can run the demo:

``` shell
python example.py
```

Or:

``` python
from fxgui import examples

examples.main()
```



<!-- DOCUMENTATION -->
## Documentation

Please read the full documentation [here](https://healkeiser.github.io/fxgui/).



<!-- CONTACT -->
## Contact

Project Link: [fxgui](https://github.com/healkeiser/fxgui)

<p align='left'>
  <a href="https://www.linkedin.com/in/valentin-beaumont">
  <img src="https://img.shields.io/badge/-LinkedIn-0A66C2?style=for-the-badge&logo=linkedin" alt="LinkedIn"/></a>
  <a href="https://www.behance.net/el1ven">
  <img src="https://img.shields.io/badge/-Behance-313131?style=for-the-badge&logo=behance" alt="Behance"/></a>
  <a href="https://twitter.com/valentinbeaumon">
  <img src="https://img.shields.io/badge/-Twitter-E1E8ED?style=for-the-badge&logo=twitter" alt="Twitter"/></a>
  <a href="https://www.instagram.com/val.beaumontart">
  <img src="https://img.shields.io/badge/-Instagram-85255b?style=for-the-badge&logo=instagram" alt="Instagram"/></a>
  <a href="https://healkeiser.gumroad.com/subscribe">
  <img src="https://img.shields.io/badge/-Gumroad-20151f?style=for-the-badge&logo=gumroad" alt="Gumroad"/></a>
</p>

[!["Buy Me A Coffee"](https://www.buymeacoffee.com/assets/img/custom_images/yellow_img.png)](https://www.buymeacoffee.com/healkeiser)
